@@ -18,11 +18,12 @@ import (
 	shadowsocks "github.com/metacubex/sing-shadowsocks"
 	"github.com/metacubex/sing-shadowsocks/shadowaead"
 	"github.com/metacubex/sing-shadowsocks/shadowaead_2022"
-	"github.com/sagernet/sing/common"
-	"github.com/sagernet/sing/common/buf"
-	"github.com/sagernet/sing/common/bufio"
-	M "github.com/sagernet/sing/common/metadata"
-	"github.com/sagernet/sing/common/network"
+	shadowtls "github.com/metacubex/sing-shadowtls"
+	"github.com/metacubex/sing/common"
+	"github.com/metacubex/sing/common/buf"
+	"github.com/metacubex/sing/common/bufio"
+	M "github.com/metacubex/sing/common/metadata"
+	"github.com/metacubex/sing/common/network"
 )
 
 type Listener struct {
@@ -31,10 +32,24 @@ type Listener struct {
 	listeners    []net.Listener
 	udpListeners []net.PacketConn
 	service      shadowsocks.Service
+	shadowTLS    *shadowtls.Service
 }
 
 var _listener *Listener
 
+// shadowTLSService is a wrapper for shadowsocks.Service to support shadowTLS.
+type shadowTLSService struct {
+	shadowsocks.Service
+	shadowTLS *shadowtls.Service
+}
+
+func (s *shadowTLSService) NewConnection(ctx context.Context, conn net.Conn, metadata M.Metadata) error {
+	if s.shadowTLS != nil {
+		return s.shadowTLS.NewConnection(ctx, conn, metadata)
+	}
+	return s.Service.NewConnection(ctx, conn, metadata)
+}
+
 func New(config LC.ShadowsocksServer, tunnel C.Tunnel, additions ...inbound.Addition) (C.MultiAddrListener, error) {
 	var sl *Listener
 	var err error
@@ -60,7 +75,8 @@ func New(config LC.ShadowsocksServer, tunnel C.Tunnel, additions ...inbound.Addi
 		return nil, err
 	}
 
-	sl = &Listener{false, config, nil, nil, nil}
+	sl = &Listener{}
+	sl.config = config
 
 	switch {
 	case config.Cipher == shadowsocks.MethodNone:
@@ -77,6 +93,51 @@ func New(config LC.ShadowsocksServer, tunnel C.Tunnel, additions ...inbound.Addi
 		return nil, err
 	}
 
+	if config.ShadowTLS.Enable {
+		buildHandshake := func(handshake LC.ShadowTLSHandshakeOptions) (handshakeConfig shadowtls.HandshakeConfig) {
+			handshakeConfig.Server = M.ParseSocksaddr(handshake.Dest)
+			handshakeConfig.Dialer = sing.NewDialer(tunnel, handshake.Proxy)
+			return
+		}
+		var handshakeForServerName map[string]shadowtls.HandshakeConfig
+		if config.ShadowTLS.Version > 1 {
+			handshakeForServerName = make(map[string]shadowtls.HandshakeConfig)
+			for serverName, serverOptions := range config.ShadowTLS.HandshakeForServerName {
+				handshakeForServerName[serverName] = buildHandshake(serverOptions)
+			}
+		}
+		var wildcardSNI shadowtls.WildcardSNI
+		switch config.ShadowTLS.WildcardSNI {
+		case "authed":
+			wildcardSNI = shadowtls.WildcardSNIAuthed
+		case "all":
+			wildcardSNI = shadowtls.WildcardSNIAll
+		default:
+			wildcardSNI = shadowtls.WildcardSNIOff
+		}
+		var shadowTLS *shadowtls.Service
+		shadowTLS, err = shadowtls.NewService(shadowtls.ServiceConfig{
+			Version:  config.ShadowTLS.Version,
+			Password: config.ShadowTLS.Password,
+			Users: common.Map(config.ShadowTLS.Users, func(it LC.ShadowTLSUser) shadowtls.User {
+				return shadowtls.User{Name: it.Name, Password: it.Password}
+			}),
+			Handshake:              buildHandshake(config.ShadowTLS.Handshake),
+			HandshakeForServerName: handshakeForServerName,
+			StrictMode:             config.ShadowTLS.StrictMode,
+			WildcardSNI:            wildcardSNI,
+			Handler:                sl.service,
+			Logger:                 log.SingLogger,
+		})
+		if err != nil {
+			return nil, err
+		}
+		sl.service = &shadowTLSService{
+			Service:   sl.service,
+			shadowTLS: shadowTLS,
+		}
+	}
+
 	for _, addr := range strings.Split(config.Listen, ",") {
 		addr := addr
 
